.. currentmodule:: sardana.pool

.. _sardana-pseudomotor-overview:

=======================
Pseudo motor overview
=======================

.. todo:: document pseudo motor overview

.. seealso:: 
    
    :ref:`sardana-pseudomotor-api`
        the pseudo motor :term:`API` 
    
    :class:`~sardana.tango.pool.PseudoMotor.PseudoMotor`
        the pseudo motor tango device :term:`API`
